pub struct Cookie {
pub domain: Vec<u8>,
pub tail_match: bool,
pub path: Vec<u8>,
pub secure: bool,
pub expires: u64,
pub name: Vec<u8>,
pub value: Vec<u8>,
pub http_only: bool,
pub prefix: CookiePrefix,
}Expand description
One parsed cookie record from a Netscape cookie file.
String-like fields are byte buffers rather than Strings because cookie jar
files seen in the wild may contain non-UTF-8 octets.
Fields
domain: Vec<u8>Cookie domain bytes with one leading dot removed.
tail_match: boolWhether the original tail-match field was TRUE, case-insensitively.
path: Vec<u8>Raw cookie path field bytes.
secure: boolWhether the original secure field was TRUE, case-insensitively.
expires: u64Expiration timestamp parsed as an unsigned integer.
name: Vec<u8>Raw cookie name bytes.
value: Vec<u8>Raw cookie value bytes.
http_only: boolWhether this line used curl’s #HttpOnly_ cookie marker.
prefix: CookiePrefixRecognized security prefix in the cookie name.